@@ -3,10 +3,16 @@
 
 require pikzie module(http://pikzie.sourceforge.net/)
 """
+
 import sys
-import pikzie
 import pyprof2html as pyhtml
 
+# warning handling
+# 'The popen2 module is deprecated.  Use the subprocess module.'
+import warnings  
+warnings.filterwarnings('ignore', category=DeprecationWarning,
+                        message=r'The popen2 module is deprecated.')
+import pikzie
 
 class TestFileTypeCheck(pikzie.TestCase):
 
@@ -17,12 +23,19 @@ class TestFileTypeCheck(pikzie.TestCase):
         self.assert_equal(False, pyhtml.check_hotshot("jotionfijeifje"))
 
 
-hotshot_testdata_path = './test/hotshot.prof'
+hotshotline_testdata_path = './test/hotshot.prof'
+hotshot_testdata_path = './test/hot.prof'
 cprof_testdata_path   = './test/cprof.prof'
-sys.stdout = open('/dev/null', 'w')
 
 class TestExecute(pikzie.TestCase):
 
+    def setup(self):
+        self.defaultstdout = sys.stdout
+        sys.stdout = open('/dev/null', 'w')
+
+    def teardown(self):
+        sys.stdout = self.defaultstdout
+
     def test_cprofraw(self):
         prof = pyhtml.Converter(cprof_testdata_path)
         prof.printout('raw')
@@ -43,3 +56,9 @@ class TestExecute(pikzie.TestCase):
         prof.printout('html')
         self.assert_equal(True, True)
 
+    def test_hotshotlinehtml(self):
+        prof = pyhtml.Converter(hotshotline_testdata_path)
+        prof.printout('html')
+        self.assert_equal(True, True)
+
+
